#!/bin/env python

'''Run all acceptance tests in order.'''

import os
import sys
import time
import test_utils as util


# the test files, in desired order
Tests = ['test_dump_python_environment.py',
         'test_python_packages.py',
         'test_filesystem_accessibility.py',
         'test_ssh_to_compute_nodes.py',
         'test_quadrature_parallel_interleaved.py',
         'test_latency_bandwidth.py',
         'test_test_pypar.py',
         'test_test_all.py']


if __name__ == '__main__':
    home_directory = os.getcwd()
    logfile = os.path.join(home_directory, 'test.log')
    if len(sys.argv) > 1:
        logfile = sys.argv[1]

    try:
        os.remove(logfile)
    except:
        pass

    # make sure we are running on a cluster machine
    (hostname, _) = util.get_hostname()
    cluster_info = util.get_cluster_info(hostname)
    if cluster_info is None:
        util.log_print_nl(logfile,
                          'Sorry, you must be running on a cluster master node.')
        util.log_print_nl(logfile, "You are on machine '%s'." % hostname)
        sys.exit(10)

    # run the tests
    for test_module in Tests:
        (import_name, _) = test_module.split('.', 1)
        test_code = ("import %s\n%s.test('%s')"
                     % (import_name, import_name, logfile))

        exec test_code
